Skip to contents

Returns a stanvar containing the Stan implementation of the hurdle-acat log-PMF used by hurdle_acat. Pass it as the stanvars argument to brm.

Usage

hurdle_acat_stanvars()

Value

A stanvars object adding the hurdle_acat_merged_lpmf (and helper acat_logit_lpmf) to the functions block of the generated Stan model.

See also

Author

Kristoffer Magnusson